# ViihdeCLI
Command-line interface for Elisa Viihde. **In Finnish.**
### Features
- Downloading recordings using [ViihdexDL](https://pypi.org/project/viihdexdl/) and [FFmpeg](https://www.ffmpeg.org/)
	- If multiple files are selected to be downloaded, downloads are queued
- Filtering recordings based on e.g. name, channel, start time, duration, show type and actors
	- Either recordings of a folder or all recordings, regardless of their folder can be listed and then filtered
- Flexible selection of recordings to be downloaded, deleted, or moved to another folder
- Duplicate search with multiple modes
### Documentation
[Documentation](https://github.com/Qotscha/viihdecli/blob/main/LUEMINUT.md) in Finnish.